==> istio-model-v1alpha3-6.3.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterRouteConfigurationMatchFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EnvoyFilterRouteConfigurationMatchFluentImpl<A extends EnvoyFilterRouteConfigurationMatchFluent<A>> extends BaseFluent<A> implements EnvoyFilterRouteConfigurationMatchFluent<A>{
  public EnvoyFilterRouteConfigurationMatchFluentImpl() {
  }
  public EnvoyFilterRouteConfigurationMatchFluentImpl(EnvoyFilterRouteConfigurationMatch instance) {
    this.withGateway(instance.getGateway()); 
    this.withName(instance.getName()); 
    this.withPortName(instance.getPortName()); 
    this.withPortNumber(instance.getPortNumber()); 
    this.withVhost(instance.getVhost()); 
  }
  private String gateway;
  private String name;
  private String portName;
  private Integer portNumber;
  private EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder vhost;
  public String getGateway() {
    return this.gateway;
  }
  public A withGateway(String gateway) {
    this.gateway=gateway; return (A) this;
  }
  public Boolean hasGateway() {
    return this.gateway != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public String getPortName() {
    return this.portName;
  }
  public A withPortName(String portName) {
    this.portName=portName; return (A) this;
  }
  public Boolean hasPortName() {
    return this.portName != null;
  }
  public Integer getPortNumber() {
    return this.portNumber;
  }
  public A withPortNumber(Integer portNumber) {
    this.portNumber=portNumber; return (A) this;
  }
  public Boolean hasPortNumber() {
    return this.portNumber != null;
  }
  
  /**
   * This method has been deprecated, please use method buildVhost instead.
   * @return The buildable object.
   */
  @Deprecated
  public EnvoyFilterRouteConfigurationMatchVirtualHostMatch getVhost() {
    return this.vhost!=null ?this.vhost.build():null;
  }
  public EnvoyFilterRouteConfigurationMatchVirtualHostMatch buildVhost() {
    return this.vhost!=null ?this.vhost.build():null;
  }
  public A withVhost(EnvoyFilterRouteConfigurationMatchVirtualHostMatch vhost) {
    _visitables.get("vhost").remove(this.vhost);
    if (vhost!=null){ this.vhost= new EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder(vhost); _visitables.get("vhost").add(this.vhost);} else { this.vhost = null; _visitables.get("vhost").remove(this.vhost); } return (A) this;
  }
  public Boolean hasVhost() {
    return this.vhost != null;
  }
  public EnvoyFilterRouteConfigurationMatchFluent.VhostNested<A> withNewVhost() {
    return new EnvoyFilterRouteConfigurationMatchFluentImpl.VhostNestedImpl();
  }
  public EnvoyFilterRouteConfigurationMatchFluent.VhostNested<A> withNewVhostLike(EnvoyFilterRouteConfigurationMatchVirtualHostMatch item) {
    return new EnvoyFilterRouteConfigurationMatchFluentImpl.VhostNestedImpl(item);
  }
  public EnvoyFilterRouteConfigurationMatchFluent.VhostNested<A> editVhost() {
    return withNewVhostLike(getVhost());
  }
  public EnvoyFilterRouteConfigurationMatchFluent.VhostNested<A> editOrNewVhost() {
    return withNewVhostLike(getVhost() != null ? getVhost(): new EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder().build());
  }
  public EnvoyFilterRouteConfigurationMatchFluent.VhostNested<A> editOrNewVhostLike(EnvoyFilterRouteConfigurationMatchVirtualHostMatch item) {
    return withNewVhostLike(getVhost() != null ? getVhost(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    EnvoyFilterRouteConfigurationMatchFluentImpl that = (EnvoyFilterRouteConfigurationMatchFluentImpl) o;
    if (gateway != null ? !gateway.equals(that.gateway) :that.gateway != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (portName != null ? !portName.equals(that.portName) :that.portName != null) return false;
    if (portNumber != null ? !portNumber.equals(that.portNumber) :that.portNumber != null) return false;
    if (vhost != null ? !vhost.equals(that.vhost) :that.vhost != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(gateway,  name,  portName,  portNumber,  vhost,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (gateway != null) { sb.append("gateway:"); sb.append(gateway + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (portName != null) { sb.append("portName:"); sb.append(portName + ","); }
    if (portNumber != null) { sb.append("portNumber:"); sb.append(portNumber + ","); }
    if (vhost != null) { sb.append("vhost:"); sb.append(vhost); }
    sb.append("}");
    return sb.toString();
  }
  class VhostNestedImpl<N> extends EnvoyFilterRouteConfigurationMatchVirtualHostMatchFluentImpl<EnvoyFilterRouteConfigurationMatchFluent.VhostNested<N>> implements EnvoyFilterRouteConfigurationMatchFluent.VhostNested<N>,Nested<N>{
    VhostNestedImpl(EnvoyFilterRouteConfigurationMatchVirtualHostMatch item) {
      this.builder = new EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder(this, item);
    }
    VhostNestedImpl() {
      this.builder = new EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder(this);
    }
    EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder builder;
    public N and() {
      return (N) EnvoyFilterRouteConfigurationMatchFluentImpl.this.withVhost(builder.build());
    }
    public N endVhost() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.7.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterRouteConfigurationMatchFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EnvoyFilterRouteConfigurationMatchFluentImpl<A extends EnvoyFilterRouteConfigurationMatchFluent<A>> extends BaseFluent<A> implements EnvoyFilterRouteConfigurationMatchFluent<A>{
  public EnvoyFilterRouteConfigurationMatchFluentImpl() {
  }
  public EnvoyFilterRouteConfigurationMatchFluentImpl(EnvoyFilterRouteConfigurationMatch instance) {
    if (instance != null) {
      this.withGateway(instance.getGateway());
      this.withName(instance.getName());
      this.withPortName(instance.getPortName());
      this.withPortNumber(instance.getPortNumber());
      this.withVhost(instance.getVhost());
    }
  }
  private String gateway;
  private String name;
  private String portName;
  private Integer portNumber;
  private EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder vhost;
  public String getGateway() {
    return this.gateway;
  }
  public A withGateway(String gateway) {
    this.gateway=gateway; return (A) this;
  }
  public Boolean hasGateway() {
    return this.gateway != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public String getPortName() {
    return this.portName;
  }
  public A withPortName(String portName) {
    this.portName=portName; return (A) this;
  }
  public Boolean hasPortName() {
    return this.portName != null;
  }
  public Integer getPortNumber() {
    return this.portNumber;
  }
  public A withPortNumber(Integer portNumber) {
    this.portNumber=portNumber; return (A) this;
  }
  public Boolean hasPortNumber() {
    return this.portNumber != null;
  }
  
  /**
   * This method has been deprecated, please use method buildVhost instead.
   * @return The buildable object.
   */
  @Deprecated
  public EnvoyFilterRouteConfigurationMatchVirtualHostMatch getVhost() {
    return this.vhost!=null ?this.vhost.build():null;
  }
  public EnvoyFilterRouteConfigurationMatchVirtualHostMatch buildVhost() {
    return this.vhost!=null ?this.vhost.build():null;
  }
  public A withVhost(EnvoyFilterRouteConfigurationMatchVirtualHostMatch vhost) {
    _visitables.get("vhost").remove(this.vhost);
    if (vhost!=null){ this.vhost= new EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder(vhost); _visitables.get("vhost").add(this.vhost);} else { this.vhost = null; _visitables.get("vhost").remove(this.vhost); } return (A) this;
  }
  public Boolean hasVhost() {
    return this.vhost != null;
  }
  public EnvoyFilterRouteConfigurationMatchFluentImpl.VhostNested<A> withNewVhost() {
    return new EnvoyFilterRouteConfigurationMatchFluentImpl.VhostNestedImpl();
  }
  public EnvoyFilterRouteConfigurationMatchFluentImpl.VhostNested<A> withNewVhostLike(EnvoyFilterRouteConfigurationMatchVirtualHostMatch item) {
    return new EnvoyFilterRouteConfigurationMatchFluentImpl.VhostNestedImpl(item);
  }
  public EnvoyFilterRouteConfigurationMatchFluentImpl.VhostNested<A> editVhost() {
    return withNewVhostLike(getVhost());
  }
  public EnvoyFilterRouteConfigurationMatchFluentImpl.VhostNested<A> editOrNewVhost() {
    return withNewVhostLike(getVhost() != null ? getVhost(): new EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder().build());
  }
  public EnvoyFilterRouteConfigurationMatchFluentImpl.VhostNested<A> editOrNewVhostLike(EnvoyFilterRouteConfigurationMatchVirtualHostMatch item) {
    return withNewVhostLike(getVhost() != null ? getVhost(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EnvoyFilterRouteConfigurationMatchFluentImpl that = (EnvoyFilterRouteConfigurationMatchFluentImpl) o;
    if (!java.util.Objects.equals(gateway, that.gateway)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(portName, that.portName)) return false;

    if (!java.util.Objects.equals(portNumber, that.portNumber)) return false;

    if (!java.util.Objects.equals(vhost, that.vhost)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(gateway,  name,  portName,  portNumber,  vhost,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (gateway != null) { sb.append("gateway:"); sb.append(gateway + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (portName != null) { sb.append("portName:"); sb.append(portName + ","); }
    if (portNumber != null) { sb.append("portNumber:"); sb.append(portNumber + ","); }
    if (vhost != null) { sb.append("vhost:"); sb.append(vhost); }
    sb.append("}");
    return sb.toString();
  }
  class VhostNestedImpl<N> extends EnvoyFilterRouteConfigurationMatchVirtualHostMatchFluentImpl<EnvoyFilterRouteConfigurationMatchFluentImpl.VhostNested<N>> implements EnvoyFilterRouteConfigurationMatchFluentImpl.VhostNested<N>,Nested<N>{
    VhostNestedImpl(EnvoyFilterRouteConfigurationMatchVirtualHostMatch item) {
      this.builder = new EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder(this, item);
    }
    VhostNestedImpl() {
      this.builder = new EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder(this);
    }
    EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder builder;
    public N and() {
      return (N) EnvoyFilterRouteConfigurationMatchFluentImpl.this.withVhost(builder.build());
    }
    public N endVhost() {
      return and();
    }
    
  }
  
}
